@@ -339,8 +339,8 @@ if ($PROGRAM_NAME eq "scripts/debrebuild.pl" && -x "scripts/debsnap.pl") {
 if (!-e $dsc_fname) {
     print(  "I: obtaining dsc using: $debsnapexe --force"
           . " --destdir . $srcpkgname $srcpkgver\n");
-    0 == system $debsnapexe, '--force', '--destdir', '.', $srcpkgname,
-      $srcpkgver
+    0 == system $debsnapexe, '--force', '--verbose', '--destdir', '.',
+      $srcpkgname, $srcpkgver
       or die "$debsnapexe failed\n";
 }
 if (!-e $dsc_fname) {
